@@ -4,4 +4,8 @@ from pc.utils import *
 from pc.qr import * 
 from pc.models import *
 from pc.detect import * 
-from pc.matrix import *
\ No newline at end of file
+from pc.matrix import *
+from pc.ai.policy import *
+from pc.ai import *
+from pc.ai.sarsa import *
+from pc.ai.ql import *
\ No newline at end of file
